package client

import (
	"gitlab.33.cn/link33/chain33-sdk-go/dapp/broker"
	//"gitlab.33.cn/link33/chain33-sdk-go/dapp/broker"
	"testing"
	"time"
)

var (
	GenesisPriv = "cc38546e9e659d15e6b4893f0ab32a06d103931a8230b0bde71459d2b27d6944"
)

func Test_InitBroker(t *testing.T){
	client, err := NewJSONClient("", "http://localhost:8901")
	if err != nil {
		t.Error(err)
	}
	resp, err :=client.InitBroker("bxhv1","chain33",GenesisPriv)
	if err != nil {
		t.Error(err)
	}
	t.Log(resp.Message)
}
func Test_EmitDataSwapInterchainEvent(t *testing.T) {
	client, err := NewJSONClient("", "http://localhost:8901")
	if err != nil {
		t.Error(err)
	}
	// 第一次存储
	resp, err := client.KVStore("test", "hello", GenesisPriv)
	if err != nil {
		t.Error(err)
	}
	time.Sleep(time.Second)
	resp, err = client.EmitDataSwapInterchainEvent("fabric&broker", "test", "test", "", GenesisPriv)
	if err != nil {
		t.Error(err)
	}
	t.Log(resp.Data)
}

func Test_InterChainGet(t *testing.T){
	client, err := NewJSONClient("", "http://localhost:8901")
	if err != nil {
		t.Error(err)
	}
	resp,err:=client.InterChainGet("test")
	if err != nil {
		t.Error(err)
	}
	t.Log(string(resp.Data))
}
func Test_QueryBrokerInfo(t *testing.T){
	client, err := NewJSONClient("", "http://localhost:8901")
	if err != nil {
		t.Error(err)
	}
	info,err:=client.QueryBrokerInfo()
	if err != nil {
		t.Error(err)
	}
	t.Logf("appid:%s,version:%s",info.GetAppChainId(),info.GetBxhId())
	meta,err:=client.QueryOutterMeta()
	if err != nil {
		t.Error(err)
	}
	t.Log(meta.Meta)
}

func Test_PollEvent(t *testing.T){
	client, err := NewJSONClient("", "http://localhost:8901")
		if err != nil {
			t.Error(err)
		}
	registerCh,eventCh,errCh:=client.RegisterTxEvent(0,"broker","EmitInterchainEvent")
	go func() {
		select {
		case event:=<-eventCh:
			t.Log(event)
		case err:=<-errCh:
			t.Error(err)
		}
	}()
	time.Sleep(5*time.Second)
	registerCh<- struct {}{}
}


func Test_UpdateIndex(t *testing.T){
	client, err := NewJSONClient("", "http://localhost:8901")
	if err != nil {
		t.Error(err)
	}
	event,err:=client.QueryOutMessage("bxhv1:chain33:local&broker-fabric&broker",1)
	if err !=nil {
		t.Error(err)
	}
	tx := broker.UpdateIndex("", event.SrcServiceID, event.GetDstServiceID(), event.GetIndex(), 0, 1)
	resp, err := client.SendTransactionSync(GenesisPriv, tx)
	if err != nil {
		t.Error(err)
	}
	t.Log(resp.Message)
}


func Test_QueryMeta(t *testing.T){
	client, err := NewJSONClient("", "http://localhost:8901")
	if err != nil {
		t.Error(err)
	}
	resp,err:=client.QueryOutMessage("bxhv1:chain33:local&broker-fabric&broker",1)
	if err !=nil {
		t.Error(err)
	}
	t.Log(resp)
	respon,err:=client.QueryInMessage("bxhv1:chain33:local&broker-fabric&broker",1)
	if err !=nil {
		t.Error(err)
	}
	t.Logf("status:%d",respon.Status)

	meta,err:=client.QueryOutterMeta()
	if err !=nil {
		t.Error(err)
	}
	t.Log(meta.Meta)
}
